Module builder

Module builder 

Structs

AgentBuilder
Builder for creating a fully wired Agent from config and context.

Functions

register_native_tools
Register the standard set of native tools onto a tool registry.