pub fn register_native_tools(tools: &mut ToolRegistry)Expand description
Register the standard set of native tools onto a tool registry.
This is the canonical list — update here when adding or removing tools.
pub fn register_native_tools(tools: &mut ToolRegistry)Register the standard set of native tools onto a tool registry.
This is the canonical list — update here when adding or removing tools.