pub struct AssistantActionGroup {
pub range: Range<usize>,
}Expand description
A grouped assistant-action slice of message history.
Each group starts at an assistant message and expands backward over any immediately preceding user messages so preserved tails keep the user prompt that led into the preserved assistant work when possible.
Fields
range: Range<usize>Trait Implementations
Sourceimpl Clone for AssistantActionGroup
impl Clone for AssistantActionGroup
Sourcefn clone(&self) -> AssistantActionGroup
fn clone(&self) -> AssistantActionGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssistantActionGroup
impl Debug for AssistantActionGroup
Sourceimpl PartialEq for AssistantActionGroup
impl PartialEq for AssistantActionGroup
Sourcefn eq(&self, other: &AssistantActionGroup) -> bool
fn eq(&self, other: &AssistantActionGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AssistantActionGroup
impl StructuralPartialEq for AssistantActionGroup