pub struct LuaCapabilityPolicy {
pub allow_native_tool_calls: bool,
pub allow_shell_exec: bool,
pub allow_http: bool,
pub allow_secrets: bool,
pub allowed_env: HashSet<String>,
}Expand description
Concrete capability policy for the shipped Lua extension runtime.
Fields
allow_native_tool_calls: boolallow_shell_exec: boolallow_http: boolallow_secrets: boolallowed_env: HashSet<String>Trait Implementations
Sourceimpl Clone for LuaCapabilityPolicy
impl Clone for LuaCapabilityPolicy
Sourcefn clone(&self) -> LuaCapabilityPolicy
fn clone(&self) -> LuaCapabilityPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LuaCapabilityPolicy
impl Debug for LuaCapabilityPolicy
Sourceimpl Default for LuaCapabilityPolicy
impl Default for LuaCapabilityPolicy
Sourceimpl PartialEq for LuaCapabilityPolicy
impl PartialEq for LuaCapabilityPolicy
Sourcefn eq(&self, other: &LuaCapabilityPolicy) -> bool
fn eq(&self, other: &LuaCapabilityPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LuaCapabilityPolicy
impl StructuralPartialEq for LuaCapabilityPolicy