pub enum GuardrailProfile {
Auto,
Generic,
Zig,
Rust,
TypeScript,
C,
Go,
Elixir,
}Expand description
Built-in guardrail starter profiles.
Variants
Auto
Infer the profile from the current project using project-detect.
Generic
Language-neutral fallback profile.
Zig
Zig starter profile.
Rust
Rust starter profile.
TypeScript
TypeScript starter profile.
C
C / C-family build-system starter profile.
Go
Go starter profile.
Elixir
Elixir starter profile.
Implementations
Sourceimpl GuardrailProfile
impl GuardrailProfile
Sourcepub fn prompt_guidance(&self) -> &'static str
pub fn prompt_guidance(&self) -> &'static str
Concise prompt guidance for the agent, tailored to this profile.
Sourcepub fn default_after_write(&self) -> &'static [&'static str]
pub fn default_after_write(&self) -> &'static [&'static str]
Default after-write check commands for this profile.
Sourcepub fn from_project_kind(kind: &ProjectKind) -> Self
pub fn from_project_kind(kind: &ProjectKind) -> Self
Resolve a detected project kind to the nearest built-in profile.