Module import

Module import 

Structs

DetectedAgentsMd
An AGENTS.md or CLAUDE.md discovered in another agent’s config.
DetectedSkill
A skill discovered in another agent’s config.
DetectedSource
A detected external agent source that imp can import from.
ImportResult
Result of importing skills.

Enums

AgentSource
Which agent tool the source comes from.
AgentsMdKind
SkipReason

Functions

detect_sources
Scan all known agent sources and return what was found.
import_agents_md
Copy an AGENTS.md/CLAUDE.md file into imp’s config as AGENTS.md.
import_skills
Copy skills from a detected source into imp’s skill directory.