pub struct MemoryStore { /* private fields */ }Expand description
Persistent memory store backed by a single markdown file.
Entries are plain text separated by  on its own line. The store enforces
a character limit, duplicate detection, and basic security scanning.
Implementations
Sourceimpl MemoryStore
impl MemoryStore
Sourcepub fn load(path: &Path, char_limit: usize) -> Result<Self>
pub fn load(path: &Path, char_limit: usize) -> Result<Self>
Load a memory store from disk. Creates the file if it doesn’t exist.
Sourcepub fn add(&mut self, content: &str) -> Result<MemoryResult>
pub fn add(&mut self, content: &str) -> Result<MemoryResult>
Append a new entry. Returns error if at capacity or content is rejected.
Sourcepub fn replace(&mut self, old_text: &str, content: &str) -> Result<MemoryResult>
pub fn replace(&mut self, old_text: &str, content: &str) -> Result<MemoryResult>
Replace the entry uniquely matching old_text with new content.
Sourcepub fn remove(&mut self, old_text: &str) -> Result<MemoryResult>
pub fn remove(&mut self, old_text: &str) -> Result<MemoryResult>
Remove the entry uniquely matching old_text.
pub fn entries(&self) -> &[String]