Module resources

Module resources 

Structs

AgentsMd
Discovered AGENTS.md content.
PromptTemplate
Discovered prompt template.
Skill
Discovered skill.
SoulDoc
Discovered soul document.

Functions

discover_agents_md
Discover instruction documents by walking up from cwd.
discover_project_soul
Discover the nearest project soul document by walking up from cwd.
discover_prompts
Discover prompt templates.
discover_skills
Discover skills from user and project directories.
discover_soul
Discover the active soul document.
extract_description
Extract the first paragraph as a description from a markdown file.
render_skill_invocation
Render a skill body for explicit slash-command invocation.
strip_frontmatter
Return markdown content without leading YAML frontmatter.
suggested_project_soul_path
Suggest where a new project soul should be created.