Module retry

Module retry 

Functions

backoff_delay
Compute how long to wait before a retry attempt.
is_retryable
Determines whether an imp_llm::Error is transient and worth retrying.
stream_with_retry
Stream an LLM call with automatic retry on transient startup errors.