pub fn truncate_head(
input: &str,
max_lines: usize,
max_bytes: usize,
) -> TruncationResultExpand description
Truncate keeping the head (first N lines/bytes). When truncated, writes full output to a temp file.
pub fn truncate_head(
input: &str,
max_lines: usize,
max_bytes: usize,
) -> TruncationResultTruncate keeping the head (first N lines/bytes). When truncated, writes full output to a temp file.