pub fn truncate_tail(
input: &str,
max_lines: usize,
max_bytes: usize,
) -> TruncationResultExpand description
Truncate keeping the tail (last N lines/bytes). When truncated, writes full output to a temp file.
pub fn truncate_tail(
input: &str,
max_lines: usize,
max_bytes: usize,
) -> TruncationResultTruncate keeping the tail (last N lines/bytes). When truncated, writes full output to a temp file.