Structs
- Detected
Agents Md - An AGENTS.md or CLAUDE.md discovered in another agent’s config.
- Detected
Skill - A skill discovered in another agent’s config.
- Detected
Source - A detected external agent source that imp can import from.
- Import
Result - Result of importing skills.
Enums
- Agent
Source - Which agent tool the source comes from.
- Agents
MdKind - Skip
Reason
Functions
- detect_
sources - Scan all known agent sources and return what was found.
- import_
agents_ md - Copy an AGENTS.md/CLAUDE.md file into imp’s config as AGENTS.md.
- import_
skills - Copy skills from a detected source into imp’s skill directory.