Structs
- Agents
Md - Discovered AGENTS.md content.
- Prompt
Template - Discovered prompt template.
- Skill
- Discovered skill.
- SoulDoc
- Discovered soul document.
Functions
- discover_
agents_ md - Discover instruction documents by walking up from cwd.
- discover_
project_ soul - Discover the nearest project soul document by walking up from cwd.
- discover_
prompts - Discover prompt templates.
- discover_
skills - Discover skills from user and project directories.
- discover_
soul - Discover the active soul document.
- extract_
description - Extract the first paragraph as a description from a markdown file.
- render_
skill_ invocation - Render a skill body for explicit slash-command invocation.
- strip_
frontmatter - Return markdown content without leading YAML frontmatter.
- suggested_
project_ soul_ path - Suggest where a new project soul should be created.